@@ -17,7 +17,7 @@ it as a stable alternative to PyQt).
 It consists of a single Python package named `qwt` which is a pure Python 
 implementation of Qwt C++ library with some limitations.
 
-.. image:: images/panorama.png
+.. image:: /../qwt/tests/data/testlauncher.png
 
 External resources:
     * Python Package Index: `PyPI`_
@@ -28,8 +28,8 @@ External resources:
 .. _GitHubPage: http://pierreraybaut.github.io/PythonQwt
 .. _GitHub: https://github.com/PierreRaybaut/PythonQwt
 """
-__version__ = '0.6.2'
-QWT_VERSION_STR = '6.1.5'
+__version__ = "0.7.0"
+QWT_VERSION_STR = "6.1.5"
 
 import warnings
 
@@ -54,8 +54,12 @@ from .scale_draw import QwtScaleDraw
 from .scale_draw import QwtAbstractScaleDraw
 from .painter import QwtPainter
 
-from .plot_series import (QwtSeriesData, QwtPointArrayData, QwtSeriesStore,
-                             QwtPlotSeriesItem)
+from .plot_series import (
+    QwtSeriesData,
+    QwtPointArrayData,
+    QwtSeriesStore,
+    QwtPlotSeriesItem,
+)
 
 from .plot_renderer import QwtPlotRenderer
 
@@ -69,63 +73,97 @@ from .plot_directpainter import QwtPlotDirectPainter
 #  Remove deprecated QwtPlotCanvas.invalidatePaintCache (replaced by replot)
 ## ============================================================================
 class QwtDoubleInterval(QwtInterval):
-    def __init__(self, minValue=0., maxValue=-1., borderFlags=None):
-        warnings.warn("`QwtDoubleInterval` has been removed in Qwt6: "\
-                      "please use `QwtInterval` instead", RuntimeWarning)
+    def __init__(self, minValue=0.0, maxValue=-1.0, borderFlags=None):
+        warnings.warn(
+            "`QwtDoubleInterval` has been removed in Qwt6: "
+            "please use `QwtInterval` instead",
+            RuntimeWarning,
+        )
         super(QwtDoubleInterval, self).__init__(minValue, maxValue, borderFlags)
+
+
 ## ============================================================================
 class QwtLog10ScaleEngine(QwtLogScaleEngine):
     def __init__(self):
-        warnings.warn("`QwtLog10ScaleEngine` has been removed in Qwt6: "\
-                      "please use `QwtLogScaleEngine` instead",
-                      RuntimeWarning)
+        warnings.warn(
+            "`QwtLog10ScaleEngine` has been removed in Qwt6: "
+            "please use `QwtLogScaleEngine` instead",
+            RuntimeWarning,
+        )
         super(QwtLog10ScaleEngine, self).__init__(10)
+
+
 ## ============================================================================
 class QwtPlotPrintFilter(object):
     def __init__(self):
-        raise NotImplementedError("`QwtPlotPrintFilter` has been removed in Qwt6: "\
-                                  "please rely on `QwtPlotRenderer` instead")
+        raise NotImplementedError(
+            "`QwtPlotPrintFilter` has been removed in Qwt6: "
+            "please rely on `QwtPlotRenderer` instead"
+        )
+
+
 ## ============================================================================
 class QwtPlotCurve(QPC):
     @property
     def Yfx(self):
-        raise NotImplementedError("`Yfx` attribute has been removed "\
-                            "(curve types are no longer implemented in Qwt6)")
+        raise NotImplementedError(
+            "`Yfx` attribute has been removed "
+            "(curve types are no longer implemented in Qwt6)"
+        )
+
     @property
     def Xfy(self):
-        raise NotImplementedError("`Yfx` attribute has been removed "\
-                            "(curve types are no longer implemented in Qwt6)")
+        raise NotImplementedError(
+            "`Yfx` attribute has been removed "
+            "(curve types are no longer implemented in Qwt6)"
+        )
+
+
 ## ============================================================================
 class QwtSymbol(QSbl):
     def draw(self, painter, *args):
-        warnings.warn("`draw` has been removed in Qwt6: "\
-                      "please rely on `drawSymbol` and `drawSymbols` instead",
-                      RuntimeWarning)
+        warnings.warn(
+            "`draw` has been removed in Qwt6: "
+            "please rely on `drawSymbol` and `drawSymbols` instead",
+            RuntimeWarning,
+        )
         from .qt.QtCore import QPointF
+
         if len(args) == 2:
             self.drawSymbols(painter, [QPointF(*args)])
         else:
             self.drawSymbol(painter, *args)
+
+
 ## ============================================================================
 class QwtPlotGrid(QPG):
     def majPen(self):
-        warnings.warn("`majPen` has been removed in Qwt6: "\
-                      "please use `majorPen` instead",
-                      RuntimeWarning)
+        warnings.warn(
+            "`majPen` has been removed in Qwt6: " "please use `majorPen` instead",
+            RuntimeWarning,
+        )
         return self.majorPen()
+
     def minPen(self):
-        warnings.warn("`minPen` has been removed in Qwt6: "\
-                      "please use `minorPen` instead",
-                      RuntimeWarning)
+        warnings.warn(
+            "`minPen` has been removed in Qwt6: " "please use `minorPen` instead",
+            RuntimeWarning,
+        )
         return self.minorPen()
+
     def setMajPen(self, *args):
-        warnings.warn("`setMajPen` has been removed in Qwt6: "\
-                      "please use `setMajorPen` instead",
-                      RuntimeWarning)
+        warnings.warn(
+            "`setMajPen` has been removed in Qwt6: " "please use `setMajorPen` instead",
+            RuntimeWarning,
+        )
         return self.setMajorPen(*args)
+
     def setMinPen(self, *args):
-        warnings.warn("`setMinPen` has been removed in Qwt6: "\
-                      "please use `setMinorPen` instead",
-                      RuntimeWarning)
+        warnings.warn(
+            "`setMinPen` has been removed in Qwt6: " "please use `setMinorPen` instead",
+            RuntimeWarning,
+        )
         return self.setMinorPen(*args)
+
+
 ## ============================================================================
