@@ -19,11 +19,21 @@ QwtLegend
    :members:
 """
 
-import numpy as np
+import math
 
-from .qt.QtGui import (QFrame, QScrollArea, QWidget, QVBoxLayout, QPalette,
-                          QApplication, QStyleOption, QStyle, QPixmap,
-                          QPainter, qDrawWinButton)
+from .qt.QtGui import (
+    QFrame,
+    QScrollArea,
+    QWidget,
+    QVBoxLayout,
+    QPalette,
+    QApplication,
+    QStyleOption,
+    QStyle,
+    QPixmap,
+    QPainter,
+    qDrawWinButton,
+)
 from .qt.QtCore import Signal, QEvent, QSize, Qt, QRect, QRectF, QPoint
 
 from .text import QwtText, QwtTextLabel
@@ -52,29 +62,29 @@ class QwtLegendData(object):
         The stockchart example implements a legend as a tree 
         with checkable items
     """
-    
+
     # enum Mode
     ReadOnly, Clickable, Checkable = list(range(3))
-    
+
     # enum Role
     ModeRole, TitleRole, IconRole = list(range(3))
     UserRole = 32
-    
+
     def __init__(self):
         self.__map = {}
-    
+
     def setValues(self, map_):
         """
         Set the legend attributes
         
-        :param dict map\_: Values
+        :param dict map_: Values
 
         .. seealso::
         
             :py:meth:`values()`
         """
         self.__map = map_
-    
+
     def values(self):
         """
         :return: Legend attributes
@@ -84,14 +94,14 @@ class QwtLegendData(object):
             :py:meth:`setValues()`
         """
         return self.__map
-    
+
     def hasRole(self, role):
         """
         :param int role: Attribute role
         :return: True, when the internal map has an entry for role
         """
         return role in self.__map
-        
+
     def setValue(self, role, data):
         """
         Set an attribute value
@@ -104,7 +114,7 @@ class QwtLegendData(object):
             :py:meth:`value()`
         """
         self.__map[role] = data
-    
+
     def value(self, role):
         """
         :param int role: Attribute role
@@ -115,13 +125,13 @@ class QwtLegendData(object):
             :py:meth:`setValue()`
         """
         return self.__map.get(role)
-    
+
     def isValid(self):
         """
         :return: True, when the internal map is empty
         """
         return len(self.__map) != 0
-    
+
     def title(self):
         """
         :return: Value of the TitleRole attribute
@@ -130,15 +140,15 @@ class QwtLegendData(object):
         if isinstance(titleValue, QwtText):
             text = titleValue
         else:
-            text.setText(titleValue)
+            text = QwtText(titleValue)
         return text
-    
+
     def icon(self):
         """
         :return: Value of the IconRole attribute
         """
         return self.value(QwtLegendData.IconRole)
-    
+
     def mode(self):
         """
         :return: Value of the ModeRole attribute
@@ -149,7 +159,6 @@ class QwtLegendData(object):
         return QwtLegendData.ReadOnly
 
 
-
 BUTTONFRAME = 2
 MARGIN = 2
 
@@ -169,22 +178,22 @@ class QwtLegendLabel_PrivateData(object):
         self.spacing = MARGIN
         self.legendData = QwtLegendData()
         self.icon = QPixmap()
-        
+
 
 class QwtLegendLabel(QwtTextLabel):
     """A widget representing something on a QwtLegend."""
-    
+
     clicked = Signal()
     pressed = Signal()
     released = Signal()
     checked = Signal(bool)
-    
+
     def __init__(self, parent=None):
         QwtTextLabel.__init__(self, parent)
         self.__data = QwtLegendLabel_PrivateData()
         self.setMargin(MARGIN)
         self.setIndent(MARGIN)
-        
+
     def setData(self, legendData):
         """
         Set the attributes of the legend label
@@ -207,7 +216,7 @@ class QwtLegendLabel(QwtTextLabel):
         if doUpdate:
             self.setUpdatesEnabled(True)
             self.update()
-    
+
     def data(self):
         """
         :return: Attributes of the label
@@ -217,7 +226,7 @@ class QwtLegendLabel(QwtTextLabel):
             :py:meth:`setData()`, :py:meth:`qwt.plot.QwtPlotItem.legendData()`
         """
         return self.__data.legendData
-    
+
     def setText(self, text):
         """
         Set the text to the legend item
@@ -228,11 +237,10 @@ class QwtLegendLabel(QwtTextLabel):
         
             :py:meth:`text()`
         """
-        flags = Qt.AlignLeft|Qt.AlignVCenter|Qt.TextExpandTabs|Qt.TextWordWrap
-        txt = text  #TODO: WTF?
-        txt.setRenderFlags(flags)
+        flags = Qt.AlignLeft | Qt.AlignVCenter | Qt.TextExpandTabs | Qt.TextWordWrap
+        text.setRenderFlags(flags)
         QwtTextLabel.setText(self, text)
-    
+
     def setItemMode(self, mode):
         """
         Set the item mode.
@@ -247,11 +255,12 @@ class QwtLegendLabel(QwtTextLabel):
         if mode != self.__data.itemMode:
             self.__data.itemMode = mode
             self.__data.isDown = False
-            self.setFocusPolicy(Qt.TabFocus if mode != QwtLegendData.ReadOnly
-                                else Qt.NoFocus)
-            self.setMargin(BUTTONFRAME+MARGIN)
+            self.setFocusPolicy(
+                Qt.TabFocus if mode != QwtLegendData.ReadOnly else Qt.NoFocus
+            )
+            self.setMargin(BUTTONFRAME + MARGIN)
             self.updateGeometry()
-    
+
     def itemMode(self):
         """
         :return: Item mode
@@ -261,7 +270,7 @@ class QwtLegendLabel(QwtTextLabel):
             :py:meth:`setItemMode()`
         """
         return self.__data.itemMode
-    
+
     def setIcon(self, icon):
         """
         Assign the icon
@@ -273,11 +282,11 @@ class QwtLegendLabel(QwtTextLabel):
             :py:meth:`icon()`, :py:meth:`qwt.plot.QwtPlotItem.legendIcon()`
         """
         self.__data.icon = icon
-        indent = self.margin()+self.__data.spacing
+        indent = self.margin() + self.__data.spacing
         if icon.width() > 0:
-            indent += icon.width()+self.__data.spacing
+            indent += icon.width() + self.__data.spacing
         self.setIndent(indent)
-    
+
     def icon(self):
         """
         :return: Pixmap representing a plot item
@@ -287,7 +296,7 @@ class QwtLegendLabel(QwtTextLabel):
             :py:meth:`setIcon()`
         """
         return self.__data.icon
-    
+
     def setSpacing(self, spacing):
         """
         Change the spacing between icon and text
@@ -301,11 +310,11 @@ class QwtLegendLabel(QwtTextLabel):
         spacing = max([spacing, 0])
         if spacing != self.__data.spacing:
             self.__data.spacing = spacing
-            indent = self.margin()+self.__data.spacing
+            indent = self.margin() + self.__data.spacing
             if self.__data.icon.width() > 0:
-                indent += self.__data.icon.width()+self.__data.spacing
+                indent += self.__data.icon.width() + self.__data.spacing
             self.setIndent(indent)
-    
+
     def spacing(self):
         """
         :return: Spacing between icon and text
@@ -315,7 +324,7 @@ class QwtLegendLabel(QwtTextLabel):
             :py:meth:`setSpacing()`
         """
         return self.__data.spacing
-    
+
     def setChecked(self, on):
         """
         Check/Uncheck a the item
@@ -331,7 +340,7 @@ class QwtLegendLabel(QwtTextLabel):
             self.blockSignals(True)
             self.setDown(on)
             self.blockSignals(isBlocked)
-    
+
     def isChecked(self):
         """
         :return: true, if the item is checked
@@ -341,7 +350,7 @@ class QwtLegendLabel(QwtTextLabel):
             :py:meth:`setChecked()`
         """
         return self.__data.itemMode == QwtLegendData.Checkable and self.isDown()
-    
+
     def setDown(self, down):
         """
         Set the item being down
@@ -364,7 +373,7 @@ class QwtLegendLabel(QwtTextLabel):
                 self.clicked.emit()
         if self.__data.itemMode == QwtLegendData.Checkable:
             self.checked.emit(self.__data.isDown)
-    
+
     def isDown(self):
         """
         :return: true, if the item is down
@@ -374,25 +383,26 @@ class QwtLegendLabel(QwtTextLabel):
             :py:meth:`setDown()`
         """
         return self.__data.isDown
-    
+
     def sizeHint(self):
         """
         :return: a size hint
         """
         sz = QwtTextLabel.sizeHint(self)
-        sz.setHeight(max([sz.height(), self.__data.icon.height()+4]))
+        sz.setHeight(max([sz.height(), self.__data.icon.height() + 4]))
         if self.__data.itemMode != QwtLegendData.ReadOnly:
             sz += buttonShift(self)
             sz = sz.expandedTo(QApplication.globalStrut())
         return sz
-    
+
     def paintEvent(self, e):
         cr = self.contentsRect()
         painter = QPainter(self)
         painter.setClipRegion(e.region())
         if self.__data.isDown:
-            qDrawWinButton(painter, 0, 0, self.width(), self.height(),
-                           self.palette(), True)
+            qDrawWinButton(
+                painter, 0, 0, self.width(), self.height(), self.palette(), True
+            )
         painter.save()
         if self.__data.isDown:
             shiftSize = buttonShift(self)
@@ -401,12 +411,11 @@ class QwtLegendLabel(QwtTextLabel):
         self.drawContents(painter)
         if not self.__data.icon.isNull():
             iconRect = QRect(cr)
-            iconRect.setX(iconRect.x()+self.margin())
+            iconRect.setX(iconRect.x() + self.margin())
             if self.__data.itemMode != QwtLegendData.ReadOnly:
-                iconRect.setX(iconRect.x()+BUTTONFRAME)
+                iconRect.setX(iconRect.x() + BUTTONFRAME)
             iconRect.setSize(self.__data.icon.size())
-            iconRect.moveCenter(QPoint(iconRect.center().x(),
-                                       cr.center().y()))
+            iconRect.moveCenter(QPoint(iconRect.center().x(), cr.center().y()))
             painter.drawPixmap(iconRect, self.__data.icon)
         painter.restore()
 
@@ -419,7 +428,7 @@ class QwtLegendLabel(QwtTextLabel):
                 self.setDown(not self.isDown())
                 return
         QwtTextLabel.mousePressEvent(self, e)
-    
+
     def mouseReleaseEvent(self, e):
         if e.button() == Qt.LeftButton:
             if self.__data.itemMode == QwtLegendData.Clickable:
@@ -452,22 +461,21 @@ class QwtLegendLabel(QwtTextLabel):
         QwtTextLabel.keyReleaseEvent(self, e)
 
 
-
 class QwtAbstractLegend(QFrame):
     def __init__(self, parent):
         QFrame.__init__(self, parent)
-        
+
     def renderLegend(self, painter, rect, fillBackground):
         raise NotImplementedError
-    
+
     def isEmpty(self):
         return 0
-        
+
     def scrollExtent(self, orientation):
         return 0
-    
+
     def updateLegend(self, itemInfo, data):
-        raise NotImplementedError        
+        raise NotImplementedError
 
 
 class Entry(object):
@@ -475,13 +483,14 @@ class Entry(object):
         self.itemInfo = None
         self.widgets = []
 
+
 class QwtLegendMap(object):
     def __init__(self):
         self.__entries = []
-    
+
     def isEmpty(self):
         return len(self.__entries) == 0
-    
+
     def insert(self, itemInfo, widgets):
         for entry in self.__entries:
             if entry.itemInfo == itemInfo:
@@ -491,36 +500,35 @@ class QwtLegendMap(object):
         newEntry.itemInfo = itemInfo
         newEntry.widgets = widgets
         self.__entries += [newEntry]
-        
+
     def remove(self, itemInfo):
         for entry in self.__entries[:]:
             if entry.itemInfo == itemInfo:
                 self.__entries.remove(entry)
                 return
-    
+
     def removeWidget(self, widget):
         for entry in self.__entries:
             while widget in entry.widgets:
                 entry.widgets.remove(widget)
-    
+
     def itemInfo(self, widget):
         if widget is not None:
             for entry in self.__entries:
                 if widget in entry.widgets:
                     return entry.itemInfo
-    
+
     def legendWidgets(self, itemInfo):
         if itemInfo is not None:
             for entry in self.__entries:
                 if entry.itemInfo == itemInfo:
                     return entry.widgets
         return []
-    
+
 
 class LegendView(QScrollArea):
     def __init__(self, parent):
         QScrollArea.__init__(self, parent)
-        self.gridLayout = None
         self.contentsWidget = QWidget(self)
         self.contentsWidget.setObjectName("QwtLegendViewContents")
         self.setWidget(self.contentsWidget)
@@ -528,7 +536,7 @@ class LegendView(QScrollArea):
         self.viewport().setObjectName("QwtLegendViewport")
         self.contentsWidget.setAutoFillBackground(False)
         self.viewport().setAutoFillBackground(False)
-    
+
     def event(self, event):
         if event.type() == QEvent.PolishRequest:
             self.setFocusPolicy(Qt.NoFocus)
@@ -541,13 +549,13 @@ class LegendView(QScrollArea):
                 h = self.contentsWidget.heightForWidth(w)
             self.contentsWidget.resize(w, h)
         return QScrollArea.event(self, event)
-    
+
     def viewportEvent(self, event):
         ok = QScrollArea.viewportEvent(self, event)
         if event.type() == QEvent.Resize:
             self.layoutContents()
         return ok
-    
+
     def viewportSize(self, w, h):
         sbHeight = self.horizontalScrollBar().sizeHint().height()
         sbWidth = self.verticalScrollBar().sizeHint().width()
@@ -562,29 +570,30 @@ class LegendView(QScrollArea):
             if w > vw and vh == ch:
                 vh -= sbHeight
         return QSize(vw, vh)
-    
+
     def layoutContents(self):
-        tl = self.gridLayout
-        if tl is None:
+        layout = self.contentsWidget.layout()
+        if layout is None:
             return
         visibleSize = self.viewport().contentsRect().size()
-        margins = tl.contentsMargins()
+        margins = layout.contentsMargins()
         margin_w = margins.left() + margins.right()
-        minW = int(tl.maxItemWidth()+margin_w)
+        minW = int(layout.maxItemWidth() + margin_w)
         w = max([visibleSize.width(), minW])
-        h = max([tl.heightForWidth(w), visibleSize.height()])
+        h = max([layout.heightForWidth(w), visibleSize.height()])
         vpWidth = self.viewportSize(w, h).width()
         if w > vpWidth:
             w = max([vpWidth, minW])
-            h = max([tl.heightForWidth(w), visibleSize.height()])
+            h = max([layout.heightForWidth(w), visibleSize.height()])
         self.contentsWidget.resize(w, h)
-        
+
 
 class QwtLegend_PrivateData(object):
     def __init__(self):
         self.itemMode = QwtLegendData.ReadOnly
-        self.view = None
-        self.itemMap = QwtLegendMap()    
+        self.view = QwtDynGridLayout()
+        self.itemMap = QwtLegendMap()
+
 
 class QwtLegend(QwtAbstractLegend):
     """
@@ -634,7 +643,7 @@ class QwtLegend(QwtAbstractLegend):
 
     clicked = Signal("PyQt_PyObject", int)
     checked = Signal("PyQt_PyObject", bool, int)
-    
+
     def __init__(self, parent=None):
         QwtAbstractLegend.__init__(self, parent)
         self.setFrameStyle(QFrame.NoFrame)
@@ -643,13 +652,13 @@ class QwtLegend(QwtAbstractLegend):
         self.__data.view.setObjectName("QwtLegendView")
         self.__data.view.setFrameStyle(QFrame.NoFrame)
         gridLayout = QwtDynGridLayout(self.__data.view.contentsWidget)
-        gridLayout.setAlignment(Qt.AlignHCenter|Qt.AlignTop)
+        gridLayout.setAlignment(Qt.AlignHCenter | Qt.AlignTop)
         self.__data.view.gridLayout = gridLayout
         self.__data.view.contentsWidget.installEventFilter(self)
         layout = QVBoxLayout(self)
         layout.setContentsMargins(0, 0, 0, 0)
         layout.addWidget(self.__data.view)
-    
+
     def setMaxColumns(self, numColumns):
         """
         Set the maximum number of entries in a row
@@ -668,7 +677,7 @@ class QwtLegend(QwtAbstractLegend):
         if tl is not None:
             tl.setMaxColumns(numColumns)
         self.updateGeometry()
-    
+
     def maxColumns(self):
         """
         :return: Maximum number of entries in a row
@@ -682,7 +691,7 @@ class QwtLegend(QwtAbstractLegend):
         if tl is not None:
             return tl.maxColumns()
         return 0
-    
+
     def setDefaultItemMode(self, mode):
         """
         Set the default mode for legend labels
@@ -705,7 +714,7 @@ class QwtLegend(QwtAbstractLegend):
             Changing the mode doesn't have any effect on existing labels.
         """
         self.__data.itemMode = mode
-    
+
     def defaultItemMode(self):
         """
         :return: Default item mode
@@ -715,7 +724,7 @@ class QwtLegend(QwtAbstractLegend):
             :py:meth:`setDefaultItemMode()`
         """
         return self.__data.itemMode
-        
+
     def contentsWidget(self):
         """
         The contents widget is the only child of the viewport of 
@@ -725,7 +734,7 @@ class QwtLegend(QwtAbstractLegend):
         :return: Container widget of the legend items
         """
         return self.__data.view.contentsWidget
-    
+
     def horizontalScrollBar(self):
         """
         :return: Horizontal scrollbar
@@ -735,7 +744,7 @@ class QwtLegend(QwtAbstractLegend):
             :py:meth:`verticalScrollBar()`
         """
         return self.__data.view.horizontalScrollBar()
-    
+
     def verticalScrollBar(self):
         """
         :return: Vertical scrollbar
@@ -745,7 +754,7 @@ class QwtLegend(QwtAbstractLegend):
             :py:meth:`horizontalScrollBar()`
         """
         return self.__data.view.verticalScrollBar()
-    
+
     def updateLegend(self, itemInfo, data):
         """
         Update the entries for an item
@@ -775,7 +784,7 @@ class QwtLegend(QwtAbstractLegend):
             self.updateTabOrder()
         for i in range(len(data)):
             self.updateWidget(widgetList[i], data[i])
-    
+
     def createWidget(self, data):
         """
         Create a widget to be inserted into the legend
@@ -795,7 +804,7 @@ class QwtLegend(QwtAbstractLegend):
         label.clicked.connect(lambda: self.itemClicked(label))
         label.checked.connect(lambda state: self.itemChecked(state, label))
         return label
-    
+
     def updateWidget(self, widget, data):
         """
         Update the widget
@@ -811,12 +820,12 @@ class QwtLegend(QwtAbstractLegend):
         
             When widget is no QwtLegendLabel updateWidget() does nothing.
         """
-        label = widget #TODO: cast to QwtLegendLabel!
+        label = widget  # TODO: cast to QwtLegendLabel!
         if label is not None:
             label.setData(data)
             if data.value(QwtLegendData.ModeRole) is None:
                 label.setItemMode(self.defaultItemMode())
-    
+
     def updateTabOrder(self):
         contentsLayout = self.__data.view.gridLayout
         if contentsLayout is not None:
@@ -826,24 +835,24 @@ class QwtLegend(QwtAbstractLegend):
                 if w is not None and item.widget():
                     QWidget.setTabOrder(w, item.widget())
                 w = item.widget()
-    
+
     def sizeHint(self):
         """Return a size hint"""
         hint = self.__data.view.contentsWidget.sizeHint()
-        hint += QSize(2*self.frameWidth(), 2*self.frameWidth())
+        hint += QSize(2 * self.frameWidth(), 2 * self.frameWidth())
         return hint
-        
+
     def heightForWidth(self, width):
         """
         :param int width: Width
         :return: The preferred height, for a width.
         """
-        width -= 2*self.frameWidth()
+        width -= 2 * self.frameWidth()
         h = self.__data.view.contentsWidget.heightForWidth(width)
         if h >= 0:
-            h += 2*self.frameWidth()
+            h += 2 * self.frameWidth()
         return h
-    
+
     def eventFilter(self, object_, event):
         """
         Handle QEvent.ChildRemoved andQEvent.LayoutRequest events 
@@ -855,19 +864,20 @@ class QwtLegend(QwtAbstractLegend):
         """
         if object_ is self.__data.view.contentsWidget:
             if event.type() == QEvent.ChildRemoved:
-                ce = event  #TODO: cast to QChildEvent
+                ce = event  # TODO: cast to QChildEvent
                 if ce.child().isWidgetType():
-                    w = ce.child()  #TODO: cast to QWidget
+                    w = ce.child()  # TODO: cast to QWidget
                     self.__data.itemMap.removeWidget(w)
             elif event.type() == QEvent.LayoutRequest:
                 self.__data.view.layoutContents()
                 if self.parentWidget() and self.parentWidget().layout() is None:
-                    QApplication.postEvent(self.parentWidget(),
-                                           QEvent(QEvent.LayoutRequest))
+                    QApplication.postEvent(
+                        self.parentWidget(), QEvent(QEvent.LayoutRequest)
+                    )
         return QwtAbstractLegend.eventFilter(self, object_, event)
-        
+
     def itemClicked(self, widget):
-#        w = self.sender()  #TODO: cast to QWidget
+        #        w = self.sender()  #TODO: cast to QWidget
         w = widget
         if w is not None:
             itemInfo = self.__data.itemMap.itemInfo(w)
@@ -876,9 +886,9 @@ class QwtLegend(QwtAbstractLegend):
                 if w in widgetList:
                     index = widgetList.index(w)
                     self.clicked.emit(itemInfo, index)
-    
+
     def itemChecked(self, on, widget):
-#        w = self.sender()  #TODO: cast to QWidget
+        #        w = self.sender()  #TODO: cast to QWidget
         w = widget
         if w is not None:
             itemInfo = self.__data.itemMap.itemInfo(w)
@@ -887,7 +897,7 @@ class QwtLegend(QwtAbstractLegend):
                 if w in widgetList:
                     index = widgetList.index(w)
                     self.checked.emit(itemInfo, on, index)
-    
+
     def renderLegend(self, painter, rect, fillBackground):
         """
         Render the legend into a given rectangle.
@@ -899,21 +909,17 @@ class QwtLegend(QwtAbstractLegend):
         if self.__data.itemMap.isEmpty():
             return
         if fillBackground:
-            if self.autoFillBackground() or\
-               self.testAttribute(Qt.WA_StyledBackground):
+            if self.autoFillBackground() or self.testAttribute(Qt.WA_StyledBackground):
                 QwtPainter.drawBackground(painter, rect, self)
-#    const QwtDynGridLayout *legendLayout = 
-#        qobject_cast<QwtDynGridLayout *>( contentsWidget()->layout() );
-        #TODO: not the exact same implementation
         legendLayout = self.__data.view.contentsWidget.layout()
         if legendLayout is None:
             return
         left, right, top, bottom = self.getContentsMargins()
         layoutRect = QRect()
-        layoutRect.setLeft(np.ceil(rect.left())+left)
-        layoutRect.setTop(np.ceil(rect.top())+top)
-        layoutRect.setRight(np.ceil(rect.right())-right)
-        layoutRect.setBottom(np.ceil(rect.bottom())-bottom)
+        layoutRect.setLeft(math.ceil(rect.left()) + left)
+        layoutRect.setTop(math.ceil(rect.top()) + top)
+        layoutRect.setRight(math.ceil(rect.right()) - right)
+        layoutRect.setBottom(math.ceil(rect.bottom()) - bottom)
         numCols = legendLayout.columnsForWidth(layoutRect.width())
         itemRects = legendLayout.layoutItems(layoutRect, numCols)
         index = 0
@@ -926,7 +932,7 @@ class QwtLegend(QwtAbstractLegend):
                 self.renderItem(painter, w, itemRects[index], fillBackground)
                 index += 1
                 painter.restore()
-                
+
     def renderItem(self, painter, widget, rect, fillBackground):
         """
         Render a legend entry into a given rectangle.
@@ -937,23 +943,27 @@ class QwtLegend(QwtAbstractLegend):
         :param bool fillBackground: When true, fill rect with the widget background
         """
         if fillBackground:
-            if widget.autoFillBackground() or\
-               widget.testAttribute(Qt.WA_StyledBackground):
+            if widget.autoFillBackground() or widget.testAttribute(
+                Qt.WA_StyledBackground
+            ):
                 QwtPainter.drawBackground(painter, rect, widget)
-        label = widget  #TODO: cast to QwtLegendLabel
+        label = widget  # TODO: cast to QwtLegendLabel
         if label is not None:
             icon = label.data().icon()
             sz = icon.defaultSize()
-            iconRect = QRectF(rect.x()+label.margin(),
-                              rect.center().y()-.5*sz.height(),
-                              sz.width(), sz.height())
+            iconRect = QRectF(
+                rect.x() + label.margin(),
+                rect.center().y() - 0.5 * sz.height(),
+                sz.width(),
+                sz.height(),
+            )
             icon.render(painter, iconRect, Qt.KeepAspectRatio)
             titleRect = QRectF(rect)
-            titleRect.setX(iconRect.right()+2*label.spacing())
+            titleRect.setX(iconRect.right() + 2 * label.spacing())
             painter.setFont(label.font())
             painter.setPen(label.palette().color(QPalette.Text))
-            label.drawText(painter, titleRect)  #TODO: cast label to QwtLegendLabel
-            
+            label.drawText(painter, titleRect)  # TODO: cast label to QwtLegendLabel
+
     def legendWidgets(self, itemInfo):
         """
         List of widgets associated to a item
@@ -961,7 +971,7 @@ class QwtLegend(QwtAbstractLegend):
         :param QVariant itemInfo: Info about an item
         """
         return self.__data.itemMap.legendWidgets(itemInfo)
-    
+
     def legendWidget(self, itemInfo):
         """
         First widget in the list of widgets associated to an item
@@ -971,7 +981,7 @@ class QwtLegend(QwtAbstractLegend):
         list_ = self.__data.itemMap.legendWidgets(itemInfo)
         if list_:
             return list_[0]
-    
+
     def itemInfo(self, widget):
         """
         Find the item that is associated to a widget
@@ -980,6 +990,6 @@ class QwtLegend(QwtAbstractLegend):
         :return: Associated item info
         """
         return self.__data.itemMap.itemInfo(widget)
-    
+
     def isEmpty(self):
         return self.__data.itemMap.isEmpty()
