@@ -14,9 +14,10 @@ QwtPlotGrid
 """
 
 from .scale_div import QwtScaleDiv
-from .plot import QwtPlotItem
+from .plot import QwtPlot, QwtPlotItem
 from .text import QwtText
 from ._math import qwtFuzzyGreaterOrEqual, qwtFuzzyLessOrEqual
+from .qthelpers import qcolor_from_str
 
 from .qt.QtGui import QPen
 from .qt.QtCore import Qt
@@ -46,19 +47,95 @@ class QwtPlotGrid(QwtPlotItem):
     The `draw()` member draws the grid within a bounding
     rectangle.
     """
-    
-    def __init__(self):
-        QwtPlotItem.__init__(self, QwtText("Grid"))
+
+    def __init__(self, title="Grid"):
+        QwtPlotItem.__init__(self, title)
         self.__data = QwtPlotGrid_PrivateData()
         self.setItemInterest(QwtPlotItem.ScaleInterest, True)
-        self.setZ(10.)
+        self.setZ(10.0)
+
+    @classmethod
+    def make(
+        cls,
+        plot=None,
+        z=None,
+        enablemajor=None,
+        enableminor=None,
+        color=None,
+        width=None,
+        style=None,
+        mincolor=None,
+        minwidth=None,
+        minstyle=None,
+    ):
+        """
+        Create and setup a new `QwtPlotGrid` object (convenience function).
         
+        :param plot: Plot to attach the curve to
+        :type plot: qwt.plot.QwtPlot or None
+        :param z: Z-value
+        :type z: float or None
+        :param enablemajor: Tuple of two boolean values (x, y) for enabling major grid lines
+        :type enablemajor: bool or None
+        :param enableminor: Tuple of two boolean values (x, y) for enabling minor grid lines
+        :type enableminor: bool or None
+        :param color: Pen color for both major and minor grid lines (default: Qt.gray)
+        :type color: QColor or str or None
+        :param width: Pen width for both major and minor grid lines (default: 1.0)
+        :type width: float or None
+        :param style: Pen style for both major and minor grid lines (default: Qt.DotLine)
+        :type style: Qt.PenStyle or None
+        :param mincolor: Pen color for minor grid lines only (default: Qt.gray)
+        :type mincolor: QColor or str or None
+        :param minwidth: Pen width for minor grid lines only (default: 1.0)
+        :type minwidth: float or None
+        :param minstyle: Pen style for minor grid lines only (default: Qt.DotLine)
+        :type minstyle: Qt.PenStyle or None
+
+        .. seealso::
+        
+            :py:meth:`setMinorPen()`, :py:meth:`setMajorPen()`
+        """
+        item = cls()
+        if z is not None:
+            item.setZ(z)
+        color = qcolor_from_str(color, Qt.gray)
+        width = 1.0 if width is None else width
+        style = Qt.DotLine if style is None else style
+        item.setPen(QPen(color, width, style))
+        if mincolor is not None or minwidth is not None or minstyle is not None:
+            mincolor = qcolor_from_str(mincolor, Qt.gray)
+            minwidth = 1.0 if width is None else minwidth
+            minstyle = Qt.DotLine if style is None else minstyle
+            item.setMinorPen(QPen(mincolor, minwidth, minstyle))
+        if enablemajor is not None:
+            if isinstance(enablemajor, tuple) and len(enablemajor) == 2:
+                item.enableX(enablemajor[0])
+                item.enableY(enablemajor[1])
+            else:
+                raise TypeError(
+                    "Invalid enablemajor %r (expecting tuple of two booleans)"
+                    % enablemajor
+                )
+        if enableminor is not None:
+            if isinstance(enableminor, tuple) and len(enableminor) == 2:
+                item.enableXMin(enableminor[0])
+                item.enableYMin(enableminor[1])
+            else:
+                raise TypeError(
+                    "Invalid enableminor %r (expecting tuple of two booleans)"
+                    % enableminor
+                )
+        if plot is not None:
+            item.attach(plot)
+        return item
+
     def rtti(self):
         """
         :return: Return `QwtPlotItem.Rtti_PlotGrid`
         """
         return QwtPlotItem.Rtti_PlotGrid
-    
+
     def enableX(self, on):
         """
         Enable or disable vertical grid lines
@@ -73,7 +150,7 @@ class QwtPlotGrid(QwtPlotItem):
             self.__data.xEnabled = on
             self.legendChanged()
             self.itemChanged()
-    
+
     def enableY(self, on):
         """
         Enable or disable horizontal grid lines
@@ -88,7 +165,7 @@ class QwtPlotGrid(QwtPlotItem):
             self.__data.yEnabled = on
             self.legendChanged()
             self.itemChanged()
-    
+
     def enableXMin(self, on):
         """
         Enable or disable  minor vertical grid lines.
@@ -103,7 +180,7 @@ class QwtPlotGrid(QwtPlotItem):
             self.__data.xMinEnabled = on
             self.legendChanged()
             self.itemChanged()
-    
+
     def enableYMin(self, on):
         """
         Enable or disable  minor horizontal grid lines.
@@ -169,15 +246,17 @@ class QwtPlotGrid(QwtPlotItem):
             color, width, style = args
             self.setPen(QPen(color, width, style))
         elif len(args) == 1:
-            pen, = args
+            (pen,) = args
             if self.__data.majorPen != pen or self.__data.minorPen != pen:
                 self.__data.majorPen = pen
                 self.__data.minorPen = pen
                 self.legendChanged()
                 self.itemChanged()
         else:
-            raise TypeError("%s().setPen() takes 1 or 3 argument(s) (%s given)"\
-                            % (self.__class__.__name__, len(args)))
+            raise TypeError(
+                "%s().setPen() takes 1 or 3 argument(s) (%s given)"
+                % (self.__class__.__name__, len(args))
+            )
 
     def setMajorPen(self, *args):
         """
@@ -210,14 +289,16 @@ class QwtPlotGrid(QwtPlotItem):
             color, width, style = args
             self.setMajorPen(QPen(color, width, style))
         elif len(args) == 1:
-            pen, = args
+            (pen,) = args
             if self.__data.majorPen != pen:
                 self.__data.majorPen = pen
                 self.legendChanged()
                 self.itemChanged()
         else:
-            raise TypeError("%s().setMajorPen() takes 1 or 3 argument(s) (%s "\
-                            "given)" % (self.__class__.__name__, len(args)))
+            raise TypeError(
+                "%s().setMajorPen() takes 1 or 3 argument(s) (%s "
+                "given)" % (self.__class__.__name__, len(args))
+            )
 
     def setMinorPen(self, *args):
         """
@@ -250,15 +331,17 @@ class QwtPlotGrid(QwtPlotItem):
             color, width, style = args
             self.setMinorPen(QPen(color, width, style))
         elif len(args) == 1:
-            pen, = args
+            (pen,) = args
             if self.__data.minorPen != pen:
                 self.__data.minorPen = pen
                 self.legendChanged()
                 self.itemChanged()
         else:
-            raise TypeError("%s().setMinorPen() takes 1 or 3 argument(s) (%s "\
-                            "given)" % (self.__class__.__name__, len(args)))
-    
+            raise TypeError(
+                "%s().setMinorPen() takes 1 or 3 argument(s) (%s "
+                "given)" % (self.__class__.__name__, len(args))
+            )
+
     def draw(self, painter, xMap, yMap, canvasRect):
         """
         Draw the grid
@@ -277,41 +360,69 @@ class QwtPlotGrid(QwtPlotItem):
         minorPen.setCapStyle(Qt.FlatCap)
         painter.setPen(minorPen)
         if self.__data.xEnabled and self.__data.xMinEnabled:
-            self.drawLines(painter, canvasRect, Qt.Vertical, xMap,
-                           self.__data.xScaleDiv.ticks(QwtScaleDiv.MinorTick))
-            self.drawLines(painter, canvasRect, Qt.Vertical, xMap,
-                           self.__data.xScaleDiv.ticks(QwtScaleDiv.MediumTick))
+            self.drawLines(
+                painter,
+                canvasRect,
+                Qt.Vertical,
+                xMap,
+                self.__data.xScaleDiv.ticks(QwtScaleDiv.MinorTick),
+            )
+            self.drawLines(
+                painter,
+                canvasRect,
+                Qt.Vertical,
+                xMap,
+                self.__data.xScaleDiv.ticks(QwtScaleDiv.MediumTick),
+            )
         if self.__data.yEnabled and self.__data.yMinEnabled:
-            self.drawLines(painter, canvasRect, Qt.Horizontal, yMap,
-                           self.__data.yScaleDiv.ticks(QwtScaleDiv.MinorTick))
-            self.drawLines(painter, canvasRect, Qt.Horizontal, yMap,
-                           self.__data.yScaleDiv.ticks(QwtScaleDiv.MediumTick))
+            self.drawLines(
+                painter,
+                canvasRect,
+                Qt.Horizontal,
+                yMap,
+                self.__data.yScaleDiv.ticks(QwtScaleDiv.MinorTick),
+            )
+            self.drawLines(
+                painter,
+                canvasRect,
+                Qt.Horizontal,
+                yMap,
+                self.__data.yScaleDiv.ticks(QwtScaleDiv.MediumTick),
+            )
         majorPen = QPen(self.__data.majorPen)
         majorPen.setCapStyle(Qt.FlatCap)
         painter.setPen(majorPen)
         if self.__data.xEnabled:
-            self.drawLines(painter, canvasRect, Qt.Vertical, xMap,
-                           self.__data.xScaleDiv.ticks(QwtScaleDiv.MajorTick))
+            self.drawLines(
+                painter,
+                canvasRect,
+                Qt.Vertical,
+                xMap,
+                self.__data.xScaleDiv.ticks(QwtScaleDiv.MajorTick),
+            )
         if self.__data.yEnabled:
-            self.drawLines(painter, canvasRect, Qt.Horizontal, yMap,
-                           self.__data.yScaleDiv.ticks(QwtScaleDiv.MajorTick))
-        
+            self.drawLines(
+                painter,
+                canvasRect,
+                Qt.Horizontal,
+                yMap,
+                self.__data.yScaleDiv.ticks(QwtScaleDiv.MajorTick),
+            )
+
     def drawLines(self, painter, canvasRect, orientation, scaleMap, values):
         x1 = canvasRect.left()
-        x2 = canvasRect.right()-1.
+        x2 = canvasRect.right() - 1.0
         y1 = canvasRect.top()
-        y2 = canvasRect.bottom()-1.
+        y2 = canvasRect.bottom() - 1.0
         for val in values:
             value = scaleMap.transform(val)
             if orientation == Qt.Horizontal:
-                if qwtFuzzyGreaterOrEqual(value, y1) and\
-                   qwtFuzzyLessOrEqual(value, y2):
+                if qwtFuzzyGreaterOrEqual(value, y1) and qwtFuzzyLessOrEqual(value, y2):
                     painter.drawLine(x1, value, x2, value)
             else:
-                if qwtFuzzyGreaterOrEqual(value, x1) and\
-                   qwtFuzzyLessOrEqual(value, x2):
+                if qwtFuzzyGreaterOrEqual(value, x1) and qwtFuzzyLessOrEqual(value, x2):
                     painter.drawLine(value, y1, value, y2)
-    
+
     def majorPen(self):
         """
         :return: the pen for the major grid lines
@@ -322,7 +433,7 @@ class QwtPlotGrid(QwtPlotItem):
             :py:meth:`setPen()`
         """
         return self.__data.majorPen
-    
+
     def minorPen(self):
         """
         :return: the pen for the minor grid lines
@@ -333,7 +444,7 @@ class QwtPlotGrid(QwtPlotItem):
             :py:meth:`setPen()`
         """
         return self.__data.minorPen
-    
+
     def xEnabled(self):
         """
         :return: True if vertical grid lines are enabled
@@ -343,7 +454,7 @@ class QwtPlotGrid(QwtPlotItem):
             :py:meth:`enableX()`
         """
         return self.__data.xEnabled
-    
+
     def yEnabled(self):
         """
         :return: True if horizontal grid lines are enabled
@@ -353,7 +464,7 @@ class QwtPlotGrid(QwtPlotItem):
             :py:meth:`enableY()`
         """
         return self.__data.yEnabled
-    
+
     def xMinEnabled(self):
         """
         :return: True if minor vertical grid lines are enabled
@@ -363,7 +474,7 @@ class QwtPlotGrid(QwtPlotItem):
             :py:meth:`enableXMin()`
         """
         return self.__data.xMinEnabled
-    
+
     def yMinEnabled(self):
         """
         :return: True if minor horizontal grid lines are enabled
@@ -373,19 +484,19 @@ class QwtPlotGrid(QwtPlotItem):
             :py:meth:`enableYMin()`
         """
         return self.__data.yMinEnabled
-    
+
     def xScaleDiv(self):
         """
         :return: the scale division of the x axis
         """
         return self.__data.xScaleDiv
-    
+
     def yScaleDiv(self):
         """
         :return: the scale division of the y axis
         """
         return self.__data.yScaleDiv
-    
+
     def updateScaleDiv(self, xScaleDiv, yScaleDiv):
         """
         Update the grid to changes of the axes scale division
@@ -399,4 +510,4 @@ class QwtPlotGrid(QwtPlotItem):
         """
         self.setXDiv(xScaleDiv)
         self.setYDiv(yScaleDiv)
-        
\ No newline at end of file
+
