@@ -30,44 +30,53 @@ from __future__ import division
 from .interval import QwtInterval
 from .scale_div import QwtScaleDiv
 from .transform import QwtLogTransform
-from .math import qwtFuzzyCompare
+from ._math import qwtFuzzyCompare
 from .transform import QwtTransform
 
 from .qt.QtCore import qFuzzyCompare
 
+import sys
+import math
 import numpy as np
 
-DBL_MAX = np.finfo(float).max
+DBL_MAX = sys.float_info.max
 LOG_MIN = 1.0e-100
 LOG_MAX = 1.0e100
 
 
-def qwtLog(base, value):
-    return np.log(value)/np.log(base)
-
 def qwtLogInterval(base, interval):
-    return QwtInterval(qwtLog(base, interval.minValue()),
-                       qwtLog(base, interval.maxValue()))
+    return QwtInterval(
+        math.log(interval.minValue(), base), math.log(interval.maxValue(), base)
+    )
+
 
 def qwtPowInterval(base, interval):
-    return QwtInterval(np.power(base, interval.minValue()),
-                       np.power(base, interval.maxValue()))
+    return QwtInterval(
+        math.pow(base, interval.minValue()), math.pow(base, interval.maxValue())
+    )
+
 
 def qwtStepSize(intervalSize, maxSteps, base):
     """this version often doesn't find the best ticks: f.e for 15: 5, 10"""
     minStep = divideInterval(intervalSize, maxSteps, base)
-    if minStep != 0.:
+    if minStep != 0.0:
         #  # ticks per interval
-        numTicks = np.ceil(abs(intervalSize/minStep))-1
+        numTicks = math.ceil(abs(intervalSize / minStep)) - 1
         #  Do the minor steps fit into the interval?
-        if qwtFuzzyCompare((numTicks+1)*abs(minStep),
-                           abs(intervalSize), intervalSize) > 0:
+        if (
+            qwtFuzzyCompare(
+                (numTicks + 1) * abs(minStep), abs(intervalSize), intervalSize
+            )
+            > 0
+        ):
             #  The minor steps doesn't fit into the interval
-            return .5*intervalSize
+            return 0.5 * intervalSize
     return minStep
 
+
 EPS = 1.0e-6
 
+
 def ceilEps(value, intervalSize):
     """
     Ceil a value, relative to an interval
@@ -80,9 +89,10 @@ def ceilEps(value, intervalSize):
     
         :py:func:`qwt.scale_engine.floorEps()`
     """
-    eps = EPS*intervalSize
-    value = (value-eps)/intervalSize
-    return np.ceil(value)*intervalSize
+    eps = EPS * intervalSize
+    value = (value - eps) / intervalSize
+    return math.ceil(value) * intervalSize
+
 
 def floorEps(value, intervalSize):
     """
@@ -96,9 +106,10 @@ def floorEps(value, intervalSize):
     
         :py:func:`qwt.scale_engine.ceilEps()`
     """
-    eps = EPS*intervalSize
-    value = (value+eps)/intervalSize
-    return np.floor(value)*intervalSize
+    eps = EPS * intervalSize
+    value = (value + eps) / intervalSize
+    return math.floor(value) * intervalSize
+
 
 def divideEps(intervalSize, numSteps):
     """
@@ -110,9 +121,10 @@ def divideEps(intervalSize, numSteps):
     :param float numSteps: Number of steps
     :return: Step size
     """
-    if numSteps == 0. or intervalSize == 0.:
-        return 0.
-    return (intervalSize-(EPS*intervalSize))/numSteps
+    if numSteps == 0.0 or intervalSize == 0.0:
+        return 0.0
+    return (intervalSize - (EPS * intervalSize)) / numSteps
+
 
 def divideInterval(intervalSize, numSteps, base):
     """
@@ -124,31 +136,31 @@ def divideInterval(intervalSize, numSteps, base):
     :return: Calculated step size
     """
     if numSteps <= 0:
-        return 0.
+        return 0.0
     v = divideEps(intervalSize, numSteps)
-    if v == 0.:
-        return 0.
+    if v == 0.0:
+        return 0.0
 
-    lx = qwtLog(base, abs(v))
-    p = np.floor(lx)
-    fraction = np.power(base, lx-p)
+    lx = math.log(abs(v), base)
+    p = math.floor(lx)
+    fraction = math.pow(base, lx - p)
     n = base
-    while n > 1 and fraction <= n/2:
-        n /= 2
-    
-    stepSize = n*np.power(base, p)
+    while n > 1 and fraction <= n // 2:
+        n //= 2
+
+    stepSize = n * math.pow(base, p)
     if v < 0:
         stepSize = -stepSize
-    
+
     return stepSize
 
 
 class QwtScaleEngine_PrivateData(object):
     def __init__(self):
         self.attributes = QwtScaleEngine.NoAttribute
-        self.lowerMargin = 0.
-        self.upperMargin = 0.
-        self.referenceValue = 0.
+        self.lowerMargin = 0.0
+        self.upperMargin = 0.0
+        self.referenceValue = 0.0
         self.base = 10
         self.transform = None  # QwtTransform
 
@@ -177,18 +189,18 @@ class QwtScaleEngine(object):
         scale will be integer multiples of the step size.
       * `QwtScaleEngine.Inverted`: Turn the scale upside down
     """
-    
+
     # enum Attribute
     NoAttribute = 0x00
     IncludeReference = 0x01
     Symmetric = 0x02
     Floating = 0x04
     Inverted = 0x08
-    
+
     def __init__(self, base=10):
         self.__data = QwtScaleEngine_PrivateData()
         self.setBase(base)
-    
+
     def autoScale(self, maxNumSteps, x1, x2, stepSize):
         """
         Align and divide an interval
@@ -200,8 +212,8 @@ class QwtScaleEngine(object):
         :return: tuple (x1, x2, stepSize)
         """
         pass
-    
-    def divideScale(self, x1, x2, maxMajorSteps, maxMinorSteps, stepSize=0.):
+
+    def divideScale(self, x1, x2, maxMajorSteps, maxMinorSteps, stepSize=0.0):
         """
         Calculate a scale division
 
@@ -213,7 +225,7 @@ class QwtScaleEngine(object):
         :return: Calculated scale division
         """
         pass
-        
+
     def setTransformation(self, transform):
         """
         Assign a transformation
@@ -232,7 +244,7 @@ class QwtScaleEngine(object):
         assert transform is None or isinstance(transform, QwtTransform)
         if transform != self.__data.transform:
             self.__data.transform = transform
-    
+
     def transformation(self):
         """
         Create and return a clone of the transformation 
@@ -247,7 +259,7 @@ class QwtScaleEngine(object):
         """
         if self.__data.transform:
             return self.__data.transform.copy()
-    
+
     def lowerMargin(self):
         """
         :return: the margin at the lower end of the scale
@@ -259,7 +271,7 @@ class QwtScaleEngine(object):
             :py:meth:`setMargins()`
         """
         return self.__data.lowerMargin
-    
+
     def upperMargin(self):
         """
         :return: the margin at the upper end of the scale
@@ -271,7 +283,7 @@ class QwtScaleEngine(object):
             :py:meth:`setMargins()`
         """
         return self.__data.upperMargin
-    
+
     def setMargins(self, lower, upper):
         """
         Specify margins at the scale's endpoints
@@ -291,9 +303,9 @@ class QwtScaleEngine(object):
             
             :py:meth:`upperMargin()`, :py:meth:`lowerMargin()`
         """
-        self.__data.lowerMargin = max([lower, 0.])
-        self.__data.upperMargin = max([upper, 0.])
-    
+        self.__data.lowerMargin = max([lower, 0.0])
+        self.__data.upperMargin = max([upper, 0.0])
+
     def divideInterval(self, intervalSize, numSteps):
         """
         Calculate a step size for a given interval
@@ -303,7 +315,7 @@ class QwtScaleEngine(object):
         :return: Step size
         """
         return divideInterval(intervalSize, numSteps, self.__data.base)
-    
+
     def contains(self, interval, value):
         """
         Check if an interval "contains" a value
@@ -320,7 +332,7 @@ class QwtScaleEngine(object):
             return False
         else:
             return True
-    
+
     def strip(self, ticks, interval):
         """
         Remove ticks from a list, that are not inside an interval
@@ -331,12 +343,10 @@ class QwtScaleEngine(object):
         """
         if not interval.isValid() or not ticks:
             return []
-        if self.contains(interval, ticks[0]) and\
-           self.contains(interval, ticks[-1]):
+        if self.contains(interval, ticks[0]) and self.contains(interval, ticks[-1]):
             return ticks
-        return [tick for tick in ticks
-                if self.contains(interval, tick)]
-    
+        return [tick for tick in ticks if self.contains(interval, tick)]
+
     def buildInterval(self, value):
         """
         Build an interval around a value
@@ -347,16 +357,16 @@ class QwtScaleEngine(object):
         :param float value: Initial value
         :return: Calculated interval
         """
-        if value == 0.:
-            delta = .5
+        if value == 0.0:
+            delta = 0.5
         else:
-            delta = abs(.5*value)
-        if DBL_MAX-delta < value:
-            return QwtInterval(DBL_MAX-delta, DBL_MAX)
-        if -DBL_MAX+delta > value:
-            return QwtInterval(-DBL_MAX, -DBL_MAX+delta)
-        return QwtInterval(value-delta, value+delta)
-    
+            delta = abs(0.5 * value)
+        if DBL_MAX - delta < value:
+            return QwtInterval(DBL_MAX - delta, DBL_MAX)
+        if -DBL_MAX + delta > value:
+            return QwtInterval(-DBL_MAX, -DBL_MAX + delta)
+        return QwtInterval(value - delta, value + delta)
+
     def setAttribute(self, attribute, on=True):
         """
         Change a scale attribute
@@ -373,7 +383,7 @@ class QwtScaleEngine(object):
             self.__data.attributes |= attribute
         else:
             self.__data.attributes &= ~attribute
-    
+
     def testAttribute(self, attribute):
         """
         :param int attribute: Attribute to be tested
@@ -384,7 +394,7 @@ class QwtScaleEngine(object):
             :py:meth:`setAttribute()`
         """
         return self.__data.attributes & attribute
-    
+
     def setAttributes(self, attributes):
         """
         Change the scale attribute
@@ -396,7 +406,7 @@ class QwtScaleEngine(object):
             :py:meth:`attributes()`
         """
         self.__data.attributes = attributes
-    
+
     def attributes(self):
         """
         :return: Scale attributes
@@ -406,7 +416,7 @@ class QwtScaleEngine(object):
             :py:meth:`setAttributes()`, :py:meth:`testAttribute()`
         """
         return self.__data.attributes
-    
+
     def setReference(self, r):
         """
         Specify a reference point
@@ -417,7 +427,7 @@ class QwtScaleEngine(object):
         `Symmetric` are active. Its default value is 0.0.
         """
         self.__data.referenceValue = r
-    
+
     def reference(self):
         """
         :return: the reference value
@@ -427,7 +437,7 @@ class QwtScaleEngine(object):
             :py:meth:`setReference()`, :py:meth:`setAttribute()`
         """
         return self.__data.referenceValue
-    
+
     def setBase(self, base):
         """
         Set the base of the scale engine
@@ -444,7 +454,7 @@ class QwtScaleEngine(object):
             :py:meth:`base()`
         """
         self.__data.base = max([base, 2])
-    
+
     def base(self):
         """
         :return: Base of the scale engine
@@ -463,10 +473,10 @@ class QwtLinearScaleEngine(QwtScaleEngine):
     The step size will fit into the pattern
     \f$\left\{ 1,2,5\right\} \cdot 10^{n}\f$, where n is an integer.
     """
-    
+
     def __init__(self, base=10):
         super(QwtLinearScaleEngine, self).__init__(base)
-    
+
     def autoScale(self, maxNumSteps, x1, x2, stepSize):
         """
         Align and divide an interval
@@ -483,16 +493,15 @@ class QwtLinearScaleEngine(QwtScaleEngine):
         """
         interval = QwtInterval(x1, x2)
         interval = interval.normalized()
-        interval.setMinValue(interval.minValue()-self.lowerMargin())
-        interval.setMaxValue(interval.maxValue()+self.upperMargin())
+        interval.setMinValue(interval.minValue() - self.lowerMargin())
+        interval.setMaxValue(interval.maxValue() + self.upperMargin())
         if self.testAttribute(QwtScaleEngine.Symmetric):
             interval = interval.symmetrize(self.reference())
         if self.testAttribute(QwtScaleEngine.IncludeReference):
             interval = interval.extend(self.reference())
-        if interval.width() == 0.:
+        if interval.width() == 0.0:
             interval = self.buildInterval(interval.minValue())
-        stepSize = divideInterval(interval.width(),
-                                  max([maxNumSteps, 1]), self.base())
+        stepSize = divideInterval(interval.width(), max([maxNumSteps, 1]), self.base())
         if not self.testAttribute(QwtScaleEngine.Floating):
             interval = self.align(interval, stepSize)
         x1 = interval.minValue()
@@ -501,8 +510,8 @@ class QwtLinearScaleEngine(QwtScaleEngine):
             x1, x2 = x2, x1
             stepSize = -stepSize
         return x1, x2, stepSize
-    
-    def divideScale(self, x1, x2, maxMajorSteps, maxMinorSteps, stepSize=0.):
+
+    def divideScale(self, x1, x2, maxMajorSteps, maxMinorSteps, stepSize=0.0):
         """
         Calculate a scale division for an interval
 
@@ -517,19 +526,18 @@ class QwtLinearScaleEngine(QwtScaleEngine):
         if interval.width() <= 0:
             return QwtScaleDiv()
         stepSize = abs(stepSize)
-        if stepSize == 0.:
+        if stepSize == 0.0:
             if maxMajorSteps < 1:
                 maxMajorSteps = 1
-            stepSize = divideInterval(interval.width(), maxMajorSteps,
-                                      self.base())
+            stepSize = divideInterval(interval.width(), maxMajorSteps, self.base())
         scaleDiv = QwtScaleDiv()
-        if stepSize != 0.:
+        if stepSize != 0.0:
             ticks = self.buildTicks(interval, stepSize, maxMinorSteps)
             scaleDiv = QwtScaleDiv(interval, ticks)
         if x1 > x2:
             scaleDiv.invert()
         return scaleDiv
-        
+
     def buildTicks(self, interval, stepSize, maxMinorSteps):
         """
         Calculate ticks for an interval
@@ -541,17 +549,16 @@ class QwtLinearScaleEngine(QwtScaleEngine):
         """
         ticks = [[] for _i in range(QwtScaleDiv.NTickTypes)]
         boundingInterval = self.align(interval, stepSize)
-        ticks[QwtScaleDiv.MajorTick] = self.buildMajorTicks(boundingInterval,
-                                                            stepSize)
+        ticks[QwtScaleDiv.MajorTick] = self.buildMajorTicks(boundingInterval, stepSize)
         if maxMinorSteps > 0:
             self.buildMinorTicks(ticks, maxMinorSteps, stepSize)
         for i in range(QwtScaleDiv.NTickTypes):
             ticks[i] = self.strip(ticks[i], interval)
             for j in range(len(ticks[i])):
-                if qwtFuzzyCompare(ticks[i][j], 0., stepSize) == 0:
-                    ticks[i][j] = 0.
+                if qwtFuzzyCompare(ticks[i][j], 0.0, stepSize) == 0:
+                    ticks[i][j] = 0.0
         return ticks
-    
+
     def buildMajorTicks(self, interval, stepSize):
         """
         Calculate major ticks for an interval
@@ -560,15 +567,15 @@ class QwtLinearScaleEngine(QwtScaleEngine):
         :param float stepSize: Step size
         :return: Calculated ticks
         """
-        numTicks = min([round(interval.width()/stepSize)+1, 10000])
+        numTicks = min([round(interval.width() / stepSize) + 1, 10000])
         if np.isnan(numTicks):
             numTicks = 0
         ticks = [interval.minValue()]
-        for i in range(1, int(numTicks-1)):
-            ticks += [interval.minValue()+i*stepSize]
+        for i in range(1, int(numTicks - 1)):
+            ticks += [interval.minValue() + i * stepSize]
         ticks += [interval.maxValue()]
         return ticks
-    
+
     def buildMinorTicks(self, ticks, maxMinorSteps, stepSize):
         """
         Calculate minor ticks for an interval
@@ -578,23 +585,23 @@ class QwtLinearScaleEngine(QwtScaleEngine):
         :param float stepSize: Step size
         """
         minStep = qwtStepSize(stepSize, maxMinorSteps, self.base())
-        if minStep == 0.:
+        if minStep == 0.0:
             return
-        numTicks = int(np.ceil(abs(stepSize/minStep))-1)
+        numTicks = int(math.ceil(abs(stepSize / minStep)) - 1)
         medIndex = -1
         if numTicks % 2:
-            medIndex = numTicks/2
+            medIndex = numTicks / 2
         for val in ticks[QwtScaleDiv.MajorTick]:
             for k in range(numTicks):
                 val += minStep
                 alignedValue = val
-                if qwtFuzzyCompare(val, 0., stepSize) == 0:
-                    alignedValue = 0.
+                if qwtFuzzyCompare(val, 0.0, stepSize) == 0:
+                    alignedValue = 0.0
                 if k == medIndex:
                     ticks[QwtScaleDiv.MediumTick] += [alignedValue]
                 else:
                     ticks[QwtScaleDiv.MinorTick] += [alignedValue]
-    
+
     def align(self, interval, stepSize):
         """
         Align an interval to a step size
@@ -608,12 +615,12 @@ class QwtLinearScaleEngine(QwtScaleEngine):
         """
         x1 = interval.minValue()
         x2 = interval.maxValue()
-        eps = .000000000001
-        if -DBL_MAX+stepSize <= x1:
+        eps = 0.000000000001
+        if -DBL_MAX + stepSize <= x1:
             x = floorEps(x1, stepSize)
             if abs(x) <= eps or not qFuzzyCompare(x1, x):
                 x1 = x
-        if DBL_MAX-stepSize >= x2:
+        if DBL_MAX - stepSize >= x2:
             x = ceilEps(x2, stepSize)
             if abs(x) <= eps or not qFuzzyCompare(x2, x):
                 x2 = x
@@ -632,10 +639,11 @@ class QwtLogScaleEngine(QwtScaleEngine):
     
         The step size as well as the margins are measured in *decades*.
     """
+
     def __init__(self, base=10):
         super(QwtLogScaleEngine, self).__init__(base)
         self.setTransformation(QwtLogTransform())
-        
+
     def autoScale(self, maxNumSteps, x1, x2, stepSize):
         """
         Align and divide an interval
@@ -653,63 +661,64 @@ class QwtLogScaleEngine(QwtScaleEngine):
         if x1 > x2:
             x1, x2 = x2, x1
         logBase = self.base()
-        interval = QwtInterval(x1/np.power(logBase, self.lowerMargin()),
-                               x2*np.power(logBase, self.upperMargin()))
+        interval = QwtInterval(
+            x1 / math.pow(logBase, self.lowerMargin()),
+            x2 * math.pow(logBase, self.upperMargin()),
+        )
         interval = interval.limited(LOG_MIN, LOG_MAX)
-        if interval.maxValue()/interval.minValue() < logBase:
+        if interval.maxValue() / interval.minValue() < logBase:
             linearScaler = QwtLinearScaleEngine()
             linearScaler.setAttributes(self.attributes())
             linearScaler.setReference(self.reference())
             linearScaler.setMargins(self.lowerMargin(), self.upperMargin())
-            
-            x1, x2, stepSize = linearScaler.autoScale(maxNumSteps,
-                                                      x1, x2, stepSize)
-            
+
+            x1, x2, stepSize = linearScaler.autoScale(maxNumSteps, x1, x2, stepSize)
+
             linearInterval = QwtInterval(x1, x2).normalized()
             linearInterval = linearInterval.limited(LOG_MIN, LOG_MAX)
-            
-            if linearInterval.maxValue()/linearInterval.minValue() < logBase:
-                if stepSize < 0.:
-                    stepSize = -qwtLog(logBase, abs(stepSize))
+
+            if linearInterval.maxValue() / linearInterval.minValue() < logBase:
+                if stepSize < 0.0:
+                    stepSize = -math.log(abs(stepSize), logBase)
                 else:
-                    stepSize = qwtLog(logBase, stepSize)
+                    stepSize = math.log(stepSize, logBase)
                 return x1, x2, stepSize
-            
-        logRef = 1.
-        if self.reference() > LOG_MIN/2:
-            logRef = min([self.reference(), LOG_MAX/2])
-        
+
+        logRef = 1.0
+        if self.reference() > LOG_MIN / 2:
+            logRef = min([self.reference(), LOG_MAX / 2])
+
         if self.testAttribute(QwtScaleEngine.Symmetric):
-            delta = max([interval.maxValue()/logRef,
-                         logRef/interval.minValue()])
-            interval.setInterval(logRef/delta, logRef*delta)
-        
+            delta = max([interval.maxValue() / logRef, logRef / interval.minValue()])
+            interval.setInterval(logRef / delta, logRef * delta)
+
         if self.testAttribute(QwtScaleEngine.IncludeReference):
             interval = interval.extend(logRef)
 
-        interval = interval.limited(LOG_MIN, LOG_MAX)        
-        
-        if interval.width() == 0.:
+        interval = interval.limited(LOG_MIN, LOG_MAX)
+
+        if interval.width() == 0.0:
             interval = self.buildInterval(interval.minValue())
-        
+
         stepSize = self.divideInterval(
-            qwtLogInterval(logBase, interval).width(), max([maxNumSteps, 1]))
-        if stepSize < 1.:
-            stepSize = 1.
-        
+            qwtLogInterval(logBase, interval).width(), max([maxNumSteps, 1])
+        )
+        if stepSize < 1.0:
+            stepSize = 1.0
+
         if not self.testAttribute(QwtScaleEngine.Floating):
             interval = self.align(interval, stepSize)
-        
+
         x1 = interval.minValue()
         x2 = interval.maxValue()
-        
+
         if self.testAttribute(QwtScaleEngine.Inverted):
             x1, x2 = x2, x1
             stepSize = -stepSize
 
         return x1, x2, stepSize
-    
-    def divideScale(self, x1, x2, maxMajorSteps, maxMinorSteps, stepSize=0.):
+
+    def divideScale(self, x1, x2, maxMajorSteps, maxMinorSteps, stepSize=0.0):
         """
         Calculate a scale division for an interval
 
@@ -722,39 +731,41 @@ class QwtLogScaleEngine(QwtScaleEngine):
         """
         interval = QwtInterval(x1, x2).normalized()
         interval = interval.limited(LOG_MIN, LOG_MAX)
-        
+
         if interval.width() <= 0:
             return QwtScaleDiv()
-        
+
         logBase = self.base()
-        
-        if interval.maxValue()/interval.minValue() < logBase:
+
+        if interval.maxValue() / interval.minValue() < logBase:
             linearScaler = QwtLinearScaleEngine()
             linearScaler.setAttributes(self.attributes())
             linearScaler.setReference(self.reference())
             linearScaler.setMargins(self.lowerMargin(), self.upperMargin())
-            return linearScaler.divideScale(x1, x2, maxMajorSteps,
-                                            maxMinorSteps, stepSize)
-        
+            return linearScaler.divideScale(
+                x1, x2, maxMajorSteps, maxMinorSteps, stepSize
+            )
+
         stepSize = abs(stepSize)
-        if stepSize == 0.:
+        if stepSize == 0.0:
             if maxMajorSteps < 1:
                 maxMajorSteps = 1
             stepSize = self.divideInterval(
-                    qwtLogInterval(logBase, interval).width(), maxMajorSteps)
-            if stepSize < 1.:
-                stepSize = 1.
-        
+                qwtLogInterval(logBase, interval).width(), maxMajorSteps
+            )
+            if stepSize < 1.0:
+                stepSize = 1.0
+
         scaleDiv = QwtScaleDiv()
-        if stepSize != 0.:
+        if stepSize != 0.0:
             ticks = self.buildTicks(interval, stepSize, maxMinorSteps)
             scaleDiv = QwtScaleDiv(interval, ticks)
-        
+
         if x1 > x2:
             scaleDiv.invert()
-        
+
         return scaleDiv
-    
+
     def buildTicks(self, interval, stepSize, maxMinorSteps):
         """
         Calculate ticks for an interval
@@ -766,14 +777,13 @@ class QwtLogScaleEngine(QwtScaleEngine):
         """
         ticks = [[] for _i in range(QwtScaleDiv.NTickTypes)]
         boundingInterval = self.align(interval, stepSize)
-        ticks[QwtScaleDiv.MajorTick] = self.buildMajorTicks(boundingInterval,
-                                                            stepSize)
+        ticks[QwtScaleDiv.MajorTick] = self.buildMajorTicks(boundingInterval, stepSize)
         if maxMinorSteps > 0:
             self.buildMinorTicks(ticks, maxMinorSteps, stepSize)
         for i in range(QwtScaleDiv.NTickTypes):
             ticks[i] = self.strip(ticks[i], interval)
         return ticks
-    
+
     def buildMajorTicks(self, interval, stepSize):
         """
         Calculate major ticks for an interval
@@ -783,15 +793,15 @@ class QwtLogScaleEngine(QwtScaleEngine):
         :return: Calculated ticks
         """
         width = qwtLogInterval(self.base(), interval).width()
-        numTicks = min([int(round(width/stepSize))+1, 10000])
+        numTicks = min([int(round(width / stepSize)) + 1, 10000])
 
-        lxmin = np.log(interval.minValue())
-        lxmax = np.log(interval.maxValue())
-        lstep = (lxmax-lxmin)/float(numTicks-1)
+        lxmin = math.log(interval.minValue())
+        lxmax = math.log(interval.maxValue())
+        lstep = (lxmax - lxmin) / float(numTicks - 1)
 
         ticks = [interval.minValue()]
-        for i in range(1, numTicks-1):
-            ticks += [np.exp(lxmin+float(i)*lstep)]
+        for i in range(1, numTicks - 1):
+            ticks += [math.exp(lxmin + float(i) * lstep)]
         ticks += [interval.maxValue()]
         return ticks
 
@@ -804,55 +814,55 @@ class QwtLogScaleEngine(QwtScaleEngine):
         :param float stepSize: Step size
         """
         logBase = self.base()
-        
+
         if stepSize < 1.1:
-            minStep = self.divideInterval(stepSize, maxMinorSteps+1)
-            if minStep == 0.:
+            minStep = self.divideInterval(stepSize, maxMinorSteps + 1)
+            if minStep == 0.0:
                 return
-            
-            numSteps = int(round(stepSize/minStep))
-            
+
+            numSteps = int(round(stepSize / minStep))
+
             mediumTickIndex = -1
             if numSteps > 2 and numSteps % 2 == 0:
-                mediumTickIndex = numSteps/2
-            
+                mediumTickIndex = numSteps / 2
+
             for v in ticks[QwtScaleDiv.MajorTick]:
-                s = logBase/numSteps
-                if s >= 1.:
-                    if not qFuzzyCompare(s, 1.):
-                        ticks[QwtScaleDiv.MinorTick] += [v*s]
+                s = logBase / numSteps
+                if s >= 1.0:
+                    if not qFuzzyCompare(s, 1.0):
+                        ticks[QwtScaleDiv.MinorTick] += [v * s]
                     for j in range(2, numSteps):
-                        ticks[QwtScaleDiv.MinorTick] += [v*j*s]
+                        ticks[QwtScaleDiv.MinorTick] += [v * j * s]
                 else:
                     for j in range(1, numSteps):
-                        tick = v + j*v*(logBase-1)/numSteps
+                        tick = v + j * v * (logBase - 1) / numSteps
                         if j == mediumTickIndex:
                             ticks[QwtScaleDiv.MediumTick] += [tick]
                         else:
                             ticks[QwtScaleDiv.MinorTick] += [tick]
-                            
+
         else:
             minStep = self.divideInterval(stepSize, maxMinorSteps)
-            if minStep == 0.:
+            if minStep == 0.0:
                 return
-            
-            if minStep < 1.:
-                minStep = 1.
-            
-            numTicks = int(round(stepSize/minStep))-1
-            
-            if qwtFuzzyCompare((numTicks+1)*minStep, stepSize, stepSize) > 0:
+
+            if minStep < 1.0:
+                minStep = 1.0
+
+            numTicks = int(round(stepSize / minStep)) - 1
+
+            if qwtFuzzyCompare((numTicks + 1) * minStep, stepSize, stepSize) > 0:
                 numTicks = 0
-            
+
             if numTicks < 1:
                 return
-            
+
             mediumTickIndex = -1
             if numTicks > 2 and numTicks % 2:
-                mediumTickIndex = numTicks/2
-            
-            minFactor = max([np.power(logBase, minStep), float(logBase)])
-            
+                mediumTickIndex = numTicks / 2
+
+            minFactor = max([math.pow(logBase, minStep), float(logBase)])
+
             for tick in ticks[QwtScaleDiv.MajorTick]:
                 for j in range(numTicks):
                     tick *= minFactor
@@ -873,15 +883,14 @@ class QwtLogScaleEngine(QwtScaleEngine):
         :return: Aligned interval
         """
         intv = qwtLogInterval(self.base(), interval)
-        
+
         x1 = floorEps(intv.minValue(), stepSize)
         if qwtFuzzyCompare(interval.minValue(), x1, stepSize) == 0:
             x1 = interval.minValue()
-        
+
         x2 = ceilEps(intv.maxValue(), stepSize)
         if qwtFuzzyCompare(interval.maxValue(), x2, stepSize) == 0:
             x2 = interval.maxValue()
-        
+
         return qwtPowInterval(self.base(), QwtInterval(x1, x2))
-        
-        
+
